@@ -3,6 +3,7 @@ RSpec::Support.require_rspec_support 'recursive_const_methods'
 module RSpec
   module Core
     # rubocop:disable Metrics/ClassLength
+
     # ExampleGroup and {Example} are the main structural elements of
     # rspec-core. Consider this example:
     #
@@ -106,6 +107,7 @@ module RSpec
       # @private
       # @macro [attach] define_example_method
       #   @!scope class
+      #   @method $1
       #   @overload $1
       #   @overload $1(&example_implementation)
       #     @param example_implementation [Block] The implementation of the example.
@@ -415,10 +417,10 @@ module RSpec
         # not be applied where they should.
         registration_collection << self
 
-        user_metadata = Metadata.build_hash_from(args)
+        @user_metadata = Metadata.build_hash_from(args)
 
         @metadata = Metadata::ExampleGroupHash.create(
-          superclass_metadata, user_metadata,
+          superclass_metadata, @user_metadata,
           superclass.method(:next_runnable_index_for),
           description, *args, &example_group_block
         )
@@ -705,8 +707,8 @@ module RSpec
 
       # @private
       def self.update_inherited_metadata(updates)
-        metadata.update(updates) do |_key, existing_group_value, _new_inherited_value|
-          existing_group_value
+        metadata.update(updates) do |key, existing_group_value, new_inherited_value|
+          @user_metadata.key?(key) ? existing_group_value : new_inherited_value
         end
 
         RSpec.configuration.configure_group(self)
@@ -793,8 +795,12 @@ module RSpec
       # @private
       def self.with_frame(name, location)
         current_stack = shared_example_group_inclusions
-        current_stack << new(name, location)
-        yield
+        if current_stack.any? { |frame| frame.shared_group_name == name }
+          raise ArgumentError, "can't include shared examples recursively"
+        else
+          current_stack << new(name, location)
+          yield
+        end
       ensure
         current_stack.pop
       end
@@ -827,11 +833,17 @@ module RSpec
       const_scope
     end
 
+    def self.remove_all_constants
+      constants.each do |constant|
+        __send__(:remove_const, constant)
+      end
+    end
+
     def self.base_name_for(group)
-      return "Anonymous" if group.description.empty?
+      return "Anonymous".dup if group.description.empty?
 
       # Convert to CamelCase.
-      name = ' ' << group.description
+      name = ' ' + group.description
       name.gsub!(/[^0-9a-zA-Z]+([0-9a-zA-Z])/) do
         match = ::Regexp.last_match[1]
         match.upcase!
